@@ -6,16 +6,24 @@
 ( cd opt/kde/share/doc/HTML/en_GB/kxkb ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/ksysguard ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/ksysguard ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/cervisia ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/cervisia ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kdesu ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kfind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kfind ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/kmail ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/kmail ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/knode ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/knode ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/klipper ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kompare ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/konsole ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/kcachegrind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/faq ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/quickstart ; rm -rf common )
@@ -28,6 +36,8 @@
 ( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/userguide ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/visualdict ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/khelpcenter/visualdict ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/kturtle ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kmenuedit ; rm -rf common )
@@ -58,6 +68,8 @@
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/6.png 6.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 7.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/7.png 7.png )
+( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf top-right-konqueror.png )
+( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 8.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 9.png )
@@ -88,6 +100,8 @@
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf bottom-left.png )
+( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf appheader.html )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf doctop1.png )
@@ -100,8 +114,12 @@
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
+( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf top-middle.png )
+( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
+( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf bottom-right.png )
+( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf doctop1a.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf 10.png )
@@ -118,6 +136,10 @@
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf header.html )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/header.html header.html )
+( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf bottom-middle.png )
+( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
+( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf top-left.png )
+( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/top-left.png top-left.png )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/en_GB/common ; rm -rf kde-localised.css.template )
@@ -228,20 +250,34 @@
 ( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmfontinst ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/kbabel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/kbabel ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/kalarm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/kalarm ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kdeprint ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kdeprint ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kicker ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/klatin ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/klatin ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/kmplot ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/kmplot ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/knotes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/knotes ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kpager ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kspell ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kspell ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/kstars ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/kstars ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kwrite ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kwrite ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/ksplashml ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/ksplashml ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kdebugdialog ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/kleopatra ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/kleopatra ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/dma ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/pci ; rm -rf common )
@@ -272,6 +308,8 @@
 ( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/pcmcia ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
+( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/opengl ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/opengl ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/processor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/en_GB/common common )
 ( cd opt/kde/share/doc/HTML/en_GB/kinfocenter/ioports ; rm -rf common )
